# Test sum package
Sau khi cài đặt xong thì dùng lệnh đưa lên
<br>
python -m twine upload --repository-url https://upload.pypi.org/legacy/ dist/*  --verbose

chi tiet <br>
https://vnhass.blogspot.com/2021/05/python-tao-1-package-python-ua-len-pip.html


#######

https://pypi.org/project/vnhass/
